@@ -92,6 +92,14 @@ class GameNode(object):
         board.push(self.move)
         return board
 
+    def san(self):
+        """
+        Gets the standard algebraic notation of the move leading to this node.
+
+        Do not call this on the root node.
+        """
+        return self.parent.board().san(self.move)
+
     def root(self):
         """Gets the root node, i.e. the game."""
         node = self
@@ -113,10 +121,11 @@ class GameNode(object):
     def starts_variation(self):
         """
         Checks if this node starts a variation (and can thus have a starting
-        comment). The beginning of the game is also the start of a variation.
+        comment). The root node does not start a variation and can have no
+        starting comment.
         """
         if not self.parent or not self.parent.variations:
-            return True
+            return False
 
         return self.parent.variations[0] != self
 
@@ -202,45 +211,68 @@ class GameNode(object):
         self.promote_to_main(move)
         return node
 
-    def export(self, exporter, comments=True, variations=True, _board=None):
+    def export(self, exporter, comments=True, variations=True, _board=None, _after_variation=False):
         if _board is None:
             _board = self.board()
 
-        for index, variation in enumerate(self.variations):
-            # Open varation.
-            if index != 0:
-                exporter.start_variation()
-
-            # Append starting comment.
-            if comments and variation.starting_comment:
-                exporter.put_starting_comment(variation.starting_comment)
+        # The mainline move goes first.
+        if self.variations:
+            main_variation = self.variations[0]
 
             # Append fullmove number.
-            exporter.put_fullmove_number(_board.turn, _board.fullmove_number, index != 0)
+            exporter.put_fullmove_number(_board.turn, _board.fullmove_number, _after_variation)
 
             # Append SAN.
-            exporter.put_move(_board, variation.move)
+            exporter.put_move(_board, main_variation.move)
 
-            # Append NAGs.
             if comments:
-                exporter.put_nags(variation.nags)
+                # Append NAGs.
+                exporter.put_nags(main_variation.nags)
 
-            # Append the comment.
-            if comments and variation.comment:
-                exporter.put_comment(variation.comment)
+                # Append the comment.
+                if main_variation.comment:
+                    exporter.put_comment(main_variation.comment)
 
-            # Recursively append the next moves.
-            _board.push(variation.move)
-            variation.export(exporter, comments, variations, _board)
-            _board.pop()
+        # Then export sidelines.
+        if variations:
+            for variation in itertools.islice(self.variations, 1, None):
+                # Start variation.
+                exporter.start_variation()
 
-            # End variation.
-            if index != 0:
+                # Append starting comment.
+                if comments and variation.starting_comment:
+                    exporter.put_starting_comment(variation.starting_comment)
+
+                # Append fullmove number.
+                exporter.put_fullmove_number(_board.turn, _board.fullmove_number, True)
+
+                # Append SAN.
+                exporter.put_move(_board, variation.move)
+
+                if comments:
+                    # Append NAGs.
+                    exporter.put_nags(variation.nags)
+
+                    # Append the comment.
+                    if variation.comment:
+                        exporter.put_comment(variation.comment)
+
+                # Recursively append the next moves.
+                _board.push(variation.move)
+                variation.export(exporter, comments, variations, _board, False)
+                _board.pop()
+
+                # End variation.
                 exporter.end_variation()
 
-            # All variations or just the main line.
-            if not variations:
-                break
+        # The mainline is continued last.
+        if self.variations:
+            main_variation = self.variations[0]
+
+            # Recursively append the next moves.
+            _board.push(main_variation.move)
+            main_variation.export(exporter, comments, variations, _board, variations and len(self.variations) > 1)
+            _board.pop()
 
     def __str__(self):
         exporter = StringExporter(columns=None)
@@ -324,8 +356,8 @@ class Game(GameNode):
                 exporter.put_header(tagname, tagvalue)
             exporter.end_headers()
 
-        if comments and self.starting_comment:
-            exporter.put_starting_comment(self.starting_comment)
+        if comments and self.comment:
+            exporter.put_starting_comment(self.comment)
 
         super(Game, self).export(exporter, comments=comments, variations=variations)
 
@@ -528,7 +560,7 @@ def read_game(handle, error_handler=_raise):
         line = handle.readline()
 
     # Movetext parser state.
-    start_comment = ""
+    starting_comment = ""
     variation_stack = collections.deque([ game ])
     board_stack = collections.deque([ game.board() ])
     in_variation = False
@@ -565,13 +597,17 @@ def read_game(handle, error_handler=_raise):
                 else:
                     line = ""
 
-                # Add the comment.
-                if in_variation:
+                if in_variation or not variation_stack[-1].parent:
+                    # Add the comment if in the middle of a variation or
+                    # directly to the game.
+                    if variation_stack[-1].comment:
+                        comment_lines.insert(0, variation_stack[-1].comment)
                     variation_stack[-1].comment = "\n".join(comment_lines).strip()
-                elif len(variation_stack) == 1:
-                    variation_stack[0].start_comment = "\n".join(comment_lines).strip()
                 else:
-                    start_comment += "\n".join(comment_lines)
+                    # Otherwise it is a starting comment.
+                    if starting_comment:
+                        comment_lines.insert(0, starting_comment)
+                    starting_comment = "\n".join(comment_lines).strip()
 
                 # Continue with the current or the next line.
                 if line:
@@ -594,13 +630,14 @@ def read_game(handle, error_handler=_raise):
                 variation_stack[-1].nags.add(NAG_DUBIOUS_MOVE)
             elif token == "(":
                 # Found a start variation token.
-                variation_stack.append(variation_stack[-1].parent)
+                if variation_stack[-1].parent:
+                    variation_stack.append(variation_stack[-1].parent)
 
-                board = copy.deepcopy(board_stack[-1])
-                board.pop()
-                board_stack.append(board)
+                    board = copy.deepcopy(board_stack[-1])
+                    board.pop()
+                    board_stack.append(board)
 
-                in_variation = False
+                    in_variation = False
             elif token == ")":
                 # Found a close variation token. Always leave at least the
                 # root node on the stack.
@@ -629,9 +666,9 @@ def read_game(handle, error_handler=_raise):
                     move = board_stack[-1].parse_san(token)
                     in_variation = True
                     variation_stack[-1] = variation_stack[-1].add_variation(move)
-                    variation_stack[-1].start_comment = start_comment.strip()
+                    variation_stack[-1].starting_comment = starting_comment
                     board_stack[-1].push(move)
-                    start_comment = ""
+                    starting_comment = ""
                 except ValueError as error:
                     if error_handler:
                         error_handler(error)
